@@ -5,6 +5,12 @@ Created on 12 Nov 2022
 
 @author: Rogier van Staveren
 """
-__version__ = "0.0.3"
 
-from axaremote.axaremote import AXARemote, AXARemoteSerial, AXARemoteTelnet
+__version__ = "0.0.6"
+
+from axaremote.axaremote import (
+    AXARemote,
+    AXARemoteError,
+    AXARemoteSerial,
+    AXARemoteTelnet,
+)
